__all__ = ['lexicon', 'impl']
from compling.analysis.sentiment.impl import SentimentAnalyzer
from compling.analysis.sentiment.lexicon import Vader, Sentiwordnet, Sentix